@@ -1,12 +1,12 @@
 #' The repr package
 #' 
-#' @details
+#' String and binary representations of objects for several formats / mime types.
+#' 
 #' The LaTeX repr of vectors needs \code{\\usepackage[inline]{enumitem}}
 #' 
 #' The LaTeX repr of functions with the \code{repr.function.highlight} option set to FALSE needs \code{\\usepackage{minted}}
 #' 
 #' @seealso \link{repr}, \link{repr-options}, \link{repr-generics}, \link{repr_text}
 #' 
-#' @docType package
 #' @name repr-package
-NULL
+"_PACKAGE"
