@@ -1,11 +1,13 @@
 html_specials <- list('&' = '&amp;', '<' = '&lt;', '>' = '&gt;')
 
-html_escape <- function(text) {
+html_escape <- function(text, do_spaces = TRUE) {
 	for (chr in names(html_specials)) {
 		text <- gsub(chr, html_specials[[chr]], text, fixed = TRUE)
 	}
-	consec_spaces <- grepl('  ', text)
-	text[consec_spaces] <- sprintf('<span style=white-space:pre-wrap>%s</span>', 	text[consec_spaces])
+	if (do_spaces) {
+		consec_spaces <- grepl('  ', text)
+		text[consec_spaces] <- sprintf('<span style=white-space:pre-wrap>%s</span>', text[consec_spaces])
+	}
 	text
 }
 
@@ -32,6 +34,14 @@ latex_escape <- function(text) {
 	gsub('\\textbackslash\\{\\}', '\\textbackslash{}', text, fixed = TRUE)
 }
 
+
+markdown_escape <- function(values) {
+	# TODO also replace Markdown
+	values <- html_escape(values, do_spaces = FALSE)
+	values <- ifelse(grepl('^\\s*$', values), '<!---->', values)
+	values
+}
+
 .escape_names <- function(obj, escape_type) {
 	# Generic function for escaping names.
 	# Depending on the object type, names, rownames and colnames may be the same or different
@@ -42,7 +52,7 @@ latex_escape <- function(text) {
 
 	obj_names <- names(obj)
 	obj_rownames <- rownames(obj)
-	obj_colnames <- colnames(obj)
+	obj_colnames <- if (length(dim(obj_names)) > 1L) colnames(obj) else NULL
 
 	detect_specials <- match.fun(paste0('any_', escape_type, '_specials'))
 	escape_specials <- match.fun(paste0(escape_type, '_escape'))
@@ -51,10 +61,10 @@ latex_escape <- function(text) {
 		names(obj) <- escape_specials(obj_names)
 	if (detect_specials(obj_rownames))
 		rownames(obj) <- escape_specials(obj_rownames)
-	if (detect_specials(obj_colnames))
+	if (length(dim(obj_names)) > 1L && detect_specials(obj_colnames))
 		colnames(obj) <- escape_specials(obj_colnames)
 
-	return(obj)
+	obj
 }
 
 .any_specials <- function(char_vec, specials_list) {
@@ -83,7 +93,8 @@ latex_escape <- function(text) {
 			vec <- escape_specials(vec) # regular character vec
 		}
 	}
-	return(vec)
+
+	vec
 }
 
 slice_row <- function(df, row) {
@@ -106,6 +117,13 @@ strindent <- function(string, indent = '\t') {
 	gsub('\n', paste0('\n', indent), paste0(indent, stripped))
 }
 
+as_name_or_na <- function(x) {
+	if (is.na(x)) '<NA>'
+	else if (is.character(x) && nchar(x) == 0) NA_character_
+	else as.name(x)
+}
+
+
 # Create the actually-used functions from the shells above.
 latex_escape_names <- function(obj) .escape_names(obj, 'latex')
 html_escape_names  <- function(obj) .escape_names(obj, 'html')
@@ -113,3 +131,48 @@ any_latex_specials <- function(char_vec) .any_specials(char_vec, latex_specials)
 any_html_specials  <- function(char_vec) .any_specials(char_vec, html_specials)
 latex_escape_vec <- function(vec) .escape_vec(vec, 'latex')
 html_escape_vec  <- function(vec) .escape_vec(vec, 'html')
+
+#' @importFrom base64enc dataURI
+data_uris <- function(..., mime = '', encoding = 'base64', files) {
+	stopifnot(length(list(...)) == 0L)
+	vapply(
+		files,
+		function(f) dataURI(mime = mime, encoding = encoding, file = f),
+		character(1L))
+}
+
+
+has_row_names <- function(x) {
+	if (is.data.frame(x))
+		.row_names_info(x) > 0
+	else
+		!is.null(rownames(x))
+}
+
+
+flatten <- function(x){
+	if (!is.data.frame(x)) return(x)
+	dfcolumns <- rle(vapply(x, is.data.frame, logical(1L)))
+	if (!any(dfcolumns$values)) return(x)
+	
+	end <- cumsum(dfcolumns$lengths)
+	start <- end - dfcolumns$lengths + 1
+	
+	parts <- mapply(function(start, end, do_flatten) {
+		if (do_flatten) flatten(x[, start:end]) else x[, start:end]
+	}, start = start, end = end, do_flatten = dfcolumns$values, SIMPLIFY = FALSE)
+	
+	names(parts) <- colnames(x)
+	do.call(cbind, parts)
+}
+
+
+partition <- function(n_items, max_items) {
+	many_items <- max_items < n_items
+	
+	# create sequences of indices to bisect rows and columns
+	if (many_items) list(
+		start = seq_len(ceiling(max_items / 2)),
+		end = seq.int(n_items - floor(max_items / 2) + 1L, n_items)
+	) else NULL
+}
