@@ -1,7 +1,5 @@
-context('reprs of lists')
-
 test_that('plain lists display correctly', {
-	expect_id_text(repr_html(list(1, 2)), '<ol>
+	expect_identical(repr_html(list(1, 2)), '<ol>
 \t<li>1</li>
 \t<li>2</li>
 </ol>
@@ -9,7 +7,7 @@ test_that('plain lists display correctly', {
 })
 
 test_that('named lists display correctly', {
-	expect_id_text(repr_html(list(a = 1, b = 2)), '<dl>
+	expect_identical(repr_html(list(a = 1, b = 2)), '<dl>
 \t<dt>$a</dt>
 \t\t<dd>1</dd>
 \t<dt>$b</dt>
@@ -20,11 +18,11 @@ test_that('named lists display correctly', {
 
 test_that('lists with unknown element types don’t display', {
 	methods::setClass('__unknown', methods::representation(n = 'character'))
-	expect_id_text(repr_html(list(1, methods::new('__unknown'))), NULL)
+	expect_identical(repr_html(list(1, methods::new('__unknown'))), NULL)
 })
 
 test_that('lists with nonexistant names work', {
-	expect_id_text(repr_html(list(a = 0, 1)), '<dl>
+	expect_identical(repr_html(list(a = 0, 1)), '<dl>
 \t<dt>$a</dt>
 \t\t<dd>0</dd>
 \t<dt>[[2]]</dt>
@@ -36,7 +34,7 @@ test_that('lists with nonexistant names work', {
 test_that('NAs can occur in list names', {
 	l <- as.list(1:2)
 	names(l) <- c(NA, NA)
-	expect_id_text(repr_html(l), '<dl>
+	expect_identical(repr_html(l), '<dl>
 \t<dt>$&lt;NA&gt;</dt>
 \t\t<dd>1</dd>
 \t<dt>$&lt;NA&gt;</dt>
@@ -44,3 +42,11 @@ test_that('NAs can occur in list names', {
 </dl>
 ')
 })
+
+test_that('Lists with empty strings as names work', {
+	l <- structure(list(1), names = '')
+	expect_identical(repr_html(l), '<ol>
+\t<li>1</li>
+</ol>
+')
+})
